import React from 'react';
import { SearchHome } from './components/SearchHome';
import { SearchPage } from './components/SearchPage';
import { AdminRoute } from './components/admin/AdminRoute';
import { useSearch } from './hooks/useSearch';
import { getBasePath } from './utils/urlUtils';

export function App() {
  const {
    searchResults,
    totalResults,
    currentPage,
    currentQuery,
    activeFilter,
    hasSearched,
    isLoading,
    handleSearch,
    handlePageChange,
    handleFilterChange
  } = useSearch();

  // Get the current path relative to the base path
  const basePath = getBasePath();
  const fullPath = window.location.pathname;
  const relativePath = fullPath.replace(basePath, '/');

  // Render admin route if path ends with /admin
  if (relativePath === '/admin') {
    return <AdminRoute />;
  }

  // Render search page or home page for all other routes
  return (
    <div className="min-h-screen bg-white">
      {!hasSearched ? (
        <SearchHome onSearch={handleSearch} />
      ) : (
        <SearchPage
          results={searchResults}
          isLoading={isLoading}
          activeFilter={activeFilter}
          currentPage={currentPage}
          currentQuery={currentQuery}
          totalResults={totalResults}
          onSearch={handleSearch}
          onFilterChange={handleFilterChange}
          onPageChange={handlePageChange}
        />
      )}
    </div>
  );
}