import React from 'react';
import { Search } from 'lucide-react';
import { getSettings } from '../services/settingsService';

interface LogoProps {
  size?: 'small' | 'large';
  onClick?: () => void;
}

export function Logo({ size = 'large', onClick }: LogoProps) {
  const settings = getSettings();
  
  const config = {
    small: {
      icon: 'h-8 w-8',
      text: 'text-xl'
    },
    large: {
      icon: 'h-12 w-12',
      text: 'text-4xl'
    }
  };

  return (
    <div 
      onClick={onClick}
      className={`flex items-center gap-2 transition-transform hover:scale-105 ${onClick ? 'cursor-pointer' : ''}`}
    >
      <Search className={`${config[size].icon} text-blue-500`} />
      <span className={`${config[size].text} font-bold bg-gradient-to-r from-blue-500 to-blue-700 bg-clip-text text-transparent`}>
        {settings.logoText}
      </span>
    </div>
  );
}