import React from 'react';
import { SearchBar } from './SearchBar';
import { SearchFilters } from './SearchFilters';
import { SearchResults } from './SearchResults';
import { Pagination } from './Pagination';
import { Logo } from './Logo';
import { Footer } from './Footer';
import { useNavigation } from '../hooks/useNavigation';
import type { SearchResult } from '../services/searchService';

interface SearchPageProps {
  results: SearchResult[];
  isLoading: boolean;
  activeFilter: string;
  currentPage: number;
  currentQuery: string;
  totalResults: number;
  onSearch: (query: string) => Promise<void>;
  onFilterChange: (filter: string) => void;
  onPageChange: (page: number) => void;
}

export function SearchPage({
  results,
  isLoading,
  activeFilter,
  currentPage,
  currentQuery,
  totalResults,
  onSearch,
  onFilterChange,
  onPageChange,
}: SearchPageProps) {
  const { goToHome } = useNavigation();

  return (
    <div className="min-h-screen flex flex-col">
      <div className="flex-1">
        <div className="px-4 py-6">
          <div className="max-w-6xl mx-auto">
            <div className="flex items-center gap-4 mb-6">
              <Logo size="small" onClick={goToHome} />
              <div className="flex-1">
                <SearchBar onSearch={onSearch} />
              </div>
            </div>
            <SearchFilters
              activeFilter={activeFilter}
              onFilterChange={onFilterChange}
            />
            <SearchResults 
              results={results} 
              isLoading={isLoading} 
              searchQuery={currentQuery}
            />
            <Pagination
              currentPage={currentPage}
              totalResults={totalResults}
              resultsPerPage={10}
              onPageChange={onPageChange}
            />
          </div>
        </div>
      </div>
      <Footer />
    </div>
  );
}