import React from 'react';
import { ExternalLink } from 'lucide-react';
import type { SearchResult } from '../services/searchService';
import { getAdsByKeyword } from '../services/adsService';
import type { Ad } from '../services/adsService';

interface SearchResultsProps {
  results: SearchResult[];
  isLoading: boolean;
  searchQuery: string;
}

function AdComponent({ ad }: { ad: Ad }) {
  return (
    <div className="max-w-2xl mb-6 p-4 border border-blue-100 rounded-lg bg-blue-50">
      <div className="flex items-center text-xs text-gray-500 mb-1">
        <span className="bg-blue-100 text-blue-800 px-2 py-0.5 rounded">Ad</span>
      </div>
      <a
        href={ad.targetUrl}
        className="group block"
        target="_blank"
        rel="noopener noreferrer"
      >
        <div className="flex items-center space-x-2 text-sm text-gray-600 mb-1">
          <span>{ad.displayUrl}</span>
          <ExternalLink className="h-4 w-4" />
        </div>
        <h2 className="text-xl text-blue-600 group-hover:underline mb-2">
          {ad.title}
        </h2>
        <p className="text-gray-600">{ad.description}</p>
      </a>
    </div>
  );
}

export function SearchResults({ results, isLoading, searchQuery }: SearchResultsProps) {
  const ads = getAdsByKeyword(searchQuery);

  if (isLoading) {
    return (
      <div className="flex justify-center items-center mt-8">
        <div className="animate-spin rounded-full h-8 w-8 border-b-2 border-blue-500"></div>
      </div>
    );
  }

  if (results.length === 0 && ads.length === 0) {
    return (
      <div className="text-center text-gray-500 mt-8">
        <p>No results found. Try a different search term.</p>
      </div>
    );
  }

  return (
    <div className="space-y-6">
      {/* Show ads first */}
      {ads.map((ad) => (
        <AdComponent key={ad.id} ad={ad} />
      ))}

      {/* Then show regular search results */}
      {results.map((result, index) => (
        <div key={index} className="max-w-2xl">
          <a
            href={result.link}
            className="group block"
            target="_blank"
            rel="noopener noreferrer"
          >
            {result.pagemap?.cse_thumbnail && (
              <img
                src={result.pagemap.cse_thumbnail[0].src}
                alt=""
                className="w-24 h-24 object-cover rounded mb-2"
              />
            )}
            <div className="flex items-center space-x-2 text-sm text-gray-600 mb-1">
              <span>{result.link}</span>
              <ExternalLink className="h-4 w-4" />
            </div>
            <h2 className="text-xl text-blue-600 group-hover:underline mb-2">
              {result.title}
            </h2>
            <p className="text-gray-600">{result.snippet}</p>
          </a>
        </div>
      ))}
    </div>
  );
}