import React from 'react';
import { Mic } from 'lucide-react';
import { useVoiceSearch } from '../hooks/useVoiceSearch';

interface VoiceSearchButtonProps {
  onSearch: (query: string) => Promise<void>;
}

export function VoiceSearchButton({ onSearch }: VoiceSearchButtonProps) {
  const { isListening, error, startListening } = useVoiceSearch(onSearch);

  return (
    <button
      onClick={startListening}
      className={`absolute right-4 p-2 rounded-full transition-colors ${
        isListening 
          ? 'bg-red-100 text-red-500 animate-pulse' 
          : 'text-gray-400 hover:text-blue-500'
      }`}
      title={error || 'Search by voice'}
      disabled={isListening}
    >
      <Mic className="h-5 w-5" />
    </button>
  );
}