import React, { useState } from 'react';
import { LogOut, Settings, FileText, LayoutDashboard } from 'lucide-react';
import { logout } from '../../services/authService';
import { SiteSettings, getSettings, updateSettings } from '../../services/settingsService';
import { PagesManager } from './pages/PagesManager';
import { AdsManager } from './ads/AdsManager';

interface AdminPanelProps {
  onLogout: () => void;
}

export function AdminPanel({ onLogout }: AdminPanelProps) {
  const [settings, setSettings] = useState<SiteSettings>(getSettings());
  const [activeTab, setActiveTab] = useState<'settings' | 'pages' | 'ads'>('settings');

  const handleLogout = () => {
    logout();
    onLogout();
  };

  const handleSubmit = (e: React.FormEvent) => {
    e.preventDefault();
    updateSettings(settings);
    alert('Settings updated successfully!');
  };

  return (
    <div className="min-h-screen bg-gray-50">
      <div className="max-w-7xl mx-auto py-6 sm:px-6 lg:px-8">
        <div className="flex justify-between items-center mb-8">
          <h1 className="text-3xl font-bold text-gray-900">Admin Dashboard</h1>
          <button
            onClick={handleLogout}
            className="flex items-center px-4 py-2 text-sm text-red-600 hover:text-red-700"
          >
            <LogOut className="h-4 w-4 mr-2" />
            Logout
          </button>
        </div>

        <div className="flex space-x-4 mb-6">
          <button
            onClick={() => setActiveTab('settings')}
            className={`flex items-center px-4 py-2 rounded-md ${
              activeTab === 'settings'
                ? 'bg-blue-100 text-blue-700'
                : 'text-gray-600 hover:bg-gray-100'
            }`}
          >
            <Settings className="h-4 w-4 mr-2" />
            Settings
          </button>
          <button
            onClick={() => setActiveTab('pages')}
            className={`flex items-center px-4 py-2 rounded-md ${
              activeTab === 'pages'
                ? 'bg-blue-100 text-blue-700'
                : 'text-gray-600 hover:bg-gray-100'
            }`}
          >
            <FileText className="h-4 w-4 mr-2" />
            Pages
          </button>
          <button
            onClick={() => setActiveTab('ads')}
            className={`flex items-center px-4 py-2 rounded-md ${
              activeTab === 'ads'
                ? 'bg-blue-100 text-blue-700'
                : 'text-gray-600 hover:bg-gray-100'
            }`}
          >
            <LayoutDashboard className="h-4 w-4 mr-2" />
            Ads
          </button>
        </div>

        <div className="bg-white shadow rounded-lg p-6">
          {activeTab === 'settings' ? (
            <form onSubmit={handleSubmit} className="space-y-6">
              {/* Existing settings form content */}
            </form>
          ) : activeTab === 'pages' ? (
            <PagesManager />
          ) : (
            <AdsManager />
          )}
        </div>
      </div>
    </div>
  );
}