import { useState, useCallback } from 'react';

export function useVoiceSearch(onSearch: (query: string) => Promise<void>) {
  const [isListening, setIsListening] = useState(false);
  const [error, setError] = useState<string | null>(null);

  const startListening = useCallback(() => {
    if (!('webkitSpeechRecognition' in window)) {
      setError('Voice recognition is not supported in your browser');
      return;
    }

    const recognition = new (window as any).webkitSpeechRecognition();
    recognition.continuous = false;
    recognition.interimResults = false;
    recognition.lang = 'en-US';

    recognition.onstart = () => {
      setIsListening(true);
      setError(null);
    };

    recognition.onend = () => {
      setIsListening(false);
    };

    recognition.onresult = (event: any) => {
      const transcript = event.results[0][0].transcript;
      onSearch(transcript);
    };

    recognition.onerror = (event: any) => {
      setError('Error occurred in recognition: ' + event.error);
      setIsListening(false);
    };

    recognition.start();
  }, [onSearch]);

  return {
    isListening,
    error,
    startListening
  };
}