import { v4 as uuidv4 } from 'uuid';

export interface CustomPage {
  id: string;
  title: string;
  slug: string;
  content: string;
  metaTitle: string;
  metaDescription: string;
  isPublished: boolean;
  createdAt: string;
  updatedAt: string;
}

export function getPages(): CustomPage[] {
  const pages = localStorage.getItem('customPages');
  return pages ? JSON.parse(pages) : [];
}

export function getPageBySlug(slug: string): CustomPage | undefined {
  const pages = getPages();
  return pages.find(page => page.slug === slug);
}

export function savePage(page: Omit<CustomPage, 'id' | 'createdAt' | 'updatedAt'>): CustomPage {
  const pages = getPages();
  const newPage: CustomPage = {
    ...page,
    id: uuidv4(),
    createdAt: new Date().toISOString(),
    updatedAt: new Date().toISOString(),
  };
  
  pages.push(newPage);
  localStorage.setItem('customPages', JSON.stringify(pages));
  return newPage;
}

export function updatePage(id: string, updates: Partial<CustomPage>): CustomPage {
  const pages = getPages();
  const index = pages.findIndex(page => page.id === id);
  
  if (index === -1) throw new Error('Page not found');
  
  const updatedPage = {
    ...pages[index],
    ...updates,
    updatedAt: new Date().toISOString(),
  };
  
  pages[index] = updatedPage;
  localStorage.setItem('customPages', JSON.stringify(pages));
  return updatedPage;
}

export function deletePage(id: string): void {
  const pages = getPages();
  const filteredPages = pages.filter(page => page.id !== id);
  localStorage.setItem('customPages', JSON.stringify(filteredPages));
}