import { SEARCH_CONFIG } from '../config/search';

export interface SearchResult {
  title: string;
  link: string;
  snippet: string;
  pagemap?: {
    cse_thumbnail?: Array<{ src: string }>;
  };
}

export interface SearchResponse {
  items: SearchResult[];
  searchInformation: {
    totalResults: string;
    formattedTotalResults: string;
  };
}

export async function performSearch(query: string, page: number = 1): Promise<SearchResponse> {
  const startIndex = (page - 1) * 10;
  
  const params = new URLSearchParams({
    key: SEARCH_CONFIG.apiKey,
    cx: SEARCH_CONFIG.searchEngineId,
    q: query,
    start: startIndex.toString(),
    num: '10',
  });
  
  const url = `${SEARCH_CONFIG.baseUrl}?${params.toString()}`;
  
  try {
    const response = await fetch(url);
    if (!response.ok) {
      const error = await response.json();
      throw new Error(error.error?.message || 'Search request failed');
    }
    return await response.json();
  } catch (error) {
    console.error('Search error:', error);
    throw error;
  }
}