export interface SiteSettings {
  siteName: string;
  logoText: string;
  faviconUrl: string;
  googleApiKey: string;
  searchEngineId: string;
  metaTitle: string;
  metaDescription: string;
}

const DEFAULT_SETTINGS: SiteSettings = {
  siteName: 'Search',
  logoText: 'Search',
  faviconUrl: '/vite.svg',
  googleApiKey: import.meta.env.VITE_GOOGLE_API_KEY,
  searchEngineId: import.meta.env.VITE_SEARCH_ENGINE_ID,
  metaTitle: 'Search Engine',
  metaDescription: 'A powerful search engine built with React'
};

export function getSettings(): SiteSettings {
  const settingsStr = localStorage.getItem('siteSettings');
  return settingsStr ? JSON.parse(settingsStr) : DEFAULT_SETTINGS;
}

export function updateSettings(settings: Partial<SiteSettings>): void {
  const currentSettings = getSettings();
  const newSettings = { ...currentSettings, ...settings };
  localStorage.setItem('siteSettings', JSON.stringify(newSettings));
  
  // Update favicon
  const favicon = document.querySelector("link[rel='icon']") as HTMLLinkElement;
  if (favicon) {
    favicon.href = newSettings.faviconUrl;
  }
  
  // Update meta tags
  document.title = newSettings.metaTitle;
  const metaDescription = document.querySelector("meta[name='description']");
  if (metaDescription) {
    metaDescription.setAttribute('content', newSettings.metaDescription);
  }
}