export function updateQueryParam(key: string, value: string): void {
  const baseUrl = getBasePath();
  const currentParams = new URLSearchParams(window.location.search);
  currentParams.set(key, value);
  
  const newUrl = `${baseUrl}${currentParams.toString() ? '?' + currentParams.toString() : ''}`;
  window.history.pushState({}, '', newUrl);
}

export function getQueryParam(key: string): string {
  const params = new URLSearchParams(window.location.search);
  return params.get(key) || '';
}

export function removeQueryParam(key: string): void {
  const baseUrl = getBasePath();
  const currentParams = new URLSearchParams(window.location.search);
  currentParams.delete(key);
  
  const newUrl = currentParams.toString() 
    ? `${baseUrl}?${currentParams.toString()}`
    : baseUrl;
    
  window.history.pushState({}, '', newUrl);
}

export function getBasePath(): string {
  // Get the current script path
  const scripts = document.getElementsByTagName('script');
  let path = '/';

  for (const script of scripts) {
    if (script.src && script.src.includes('assets/')) {
      const urlParts = script.src.split('/');
      // Remove filename and 'assets' directory
      urlParts.pop();
      urlParts.pop();
      // Get the path relative to domain
      const pathParts = new URL(urlParts.join('/')).pathname.split('/');
      // Remove empty parts and join
      path = '/' + pathParts.filter(Boolean).join('/') + '/';
      break;
    }
  }

  return path;
}